@@ -93,9 +93,12 @@ Control::~Control() {
   delete m_commandScheduler;
   delete m_variables;
 
+  delete m_viewManager;
+
   delete m_ui;
   delete m_display;
   delete m_core;
+  delete m_scheduler;
 
   delete m_clientInfo;
 }
@@ -107,7 +110,7 @@ Control::initialize() {
   display::Window::slot_unschedule(rak::make_mem_fun(m_display, &display::Manager::unschedule));
   display::Window::slot_adjust(rak::make_mem_fun(m_display, &display::Manager::adjust_layout));
 
-  m_core->get_poll_manager()->get_http_stack()->set_user_agent(std::string(PACKAGE "/" VERSION "/") + torrent::version());
+  m_core->get_poll_manager()->get_http_stack()->set_user_agent(USER_AGENT);
 
   m_core->initialize_second();
   m_core->listen_open();
