@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -71,6 +71,9 @@ class CurlStack {
   const std::string&  http_proxy() const                   { return m_httpProxy; }
   void                set_http_proxy(const std::string& s) { m_httpProxy = s; }
 
+  const std::string&  bind_address() const                   { return m_bindAddress; }
+  void                set_bind_address(const std::string& s) { m_bindAddress = s; }
+
   static void         global_init();
   static void         global_cleanup();
 
@@ -89,6 +92,7 @@ class CurlStack {
 
   std::string         m_userAgent;
   std::string         m_httpProxy;
+  std::string         m_bindAddress;
 };
 
 }
