@@ -109,8 +109,11 @@ DownloadStore::save(Download* d) {
   d->bencode()->get_key("rtorrent").insert_key("total_uploaded", d->download()->up_rate()->total());
   d->bencode()->get_key("rtorrent").insert_key("chunks_done", d->download()->chunks_done());
 
-  torrent::resume_save_addresses(*d->download(), d->download()->bencode()->get_key("libtorrent_resume"));
-  torrent::resume_save_file_priorities(*d->download(), d->download()->bencode()->get_key("libtorrent_resume"));
+  torrent::Object& resumeObject = d->download()->bencode()->get_key("libtorrent_resume");
+
+  torrent::resume_save_addresses(*d->download(), resumeObject);
+  torrent::resume_save_file_priorities(*d->download(), resumeObject);
+  torrent::resume_save_tracker_settings(*d->download(), resumeObject);
 
   f << *d->bencode();
 
@@ -163,7 +166,7 @@ DownloadStore::is_correct_format(std::string f) {
 
   for (std::string::const_iterator itr = f.begin(); itr != f.end() - 8; ++itr)
     if (!(*itr >= '0' && *itr <= '9') &&
-	!(*itr >= 'A' && *itr <= 'F'))
+        !(*itr >= 'A' && *itr <= 'F'))
       return false;
 
   return true;
@@ -171,7 +174,7 @@ DownloadStore::is_correct_format(std::string f) {
 
 std::string
 DownloadStore::create_filename(Download* d) {
-  return m_path + rak::transform_hex(d->info_hash()) + ".torrent";
+  return m_path + rak::transform_hex(d->download()->info_hash()) + ".torrent";
 }
 
 }
