@@ -39,6 +39,7 @@
 #include <unistd.h>
 #include <sys/ioctl.h>
 #include <sys/termios.h>
+#include <torrent/exceptions.h>
 
 #include "canvas.h"
 
@@ -52,6 +53,28 @@ Canvas::resize(int x, int y, int w, int h) {
   mvwin(m_window, y, x);
 }
 
+void
+Canvas::print_attributes(unsigned int x, unsigned int y, const char* first, const char* last, const attributes_list* attributes) {
+  move(x, y);
+
+  int attr = A_NORMAL;
+  attributes_list::const_iterator attrItr = attributes->begin();
+
+  while (first != last) {
+    if (attrItr != attributes->end() && attrItr->position() <= first) {
+      attr = attrItr->attributes();
+      // Set colors or something.
+
+      attrItr++;
+      continue;
+    }
+
+    waddch(m_window, *first++ | attr);
+  }
+
+  // Reset the color.
+}
+
 void
 Canvas::initialize() {
   if (m_isInitialized)
