@@ -170,7 +170,11 @@ print_download_info(char* first, char* last, core::Download* d) {
 
 char*
 print_download_status(char* first, char* last, core::Download* d) {
-  if (!d->is_active())
+  if (d->is_active())
+    ;
+  else if (d->variable_value("hashing") != 0)
+    first = print_buffer(first, last, "Hashing: ");
+  else if (!d->is_active())
     first = print_buffer(first, last, "Inactive: ");
 
   if (d->is_hash_checking()) {
