@@ -46,28 +46,44 @@ Window::SlotTimer  Window::m_slotSchedule;
 Window::SlotWindow Window::m_slotUnschedule;
 Window::Slot       Window::m_slotAdjust;
 
-Window::Window(Canvas* c, bool d, int h) :
-  m_canvas(c),
-  m_active(true),
-  m_dynamic(d),
-  m_minHeight(h) {
+// When constructing the window we set flag_offscreen so that redraw
+// doesn't get triggered until after a successful Frame::balance call.
+
+Window::Window(Canvas* canvas, int flags, extent_type minWidth, extent_type minHeight, extent_type maxWidth, extent_type maxHeight) :
+  m_canvas(canvas),
+  m_flags(flags | flag_offscreen),
+
+  m_minWidth(minWidth),
+  m_minHeight(minHeight),
+
+  m_maxWidth(maxWidth),
+  m_maxHeight(maxHeight) {
 
   m_taskUpdate.set_slot(rak::mem_fn(this, &Window::redraw));
 }
 
 Window::~Window() {
-  m_slotUnschedule(this);
+  if (is_active())
+    m_slotUnschedule(this);
+
   delete m_canvas;
 }
 
 void
-Window::set_active(bool a) {
-  if (a)
-    mark_dirty();
-  else
-    m_slotUnschedule(this);
+Window::set_active(bool state) {
+  if (state == is_active())
+    return;
 
-  m_active = a;
+  if (state) {
+    // Set offscreen so we don't try rendering before Frame::balance
+    // has been called.
+    m_flags |= flag_active | flag_offscreen;
+    mark_dirty();
+
+  } else {
+    m_flags &= ~flag_active;
+    m_slotUnschedule(this);
+  }
 }
 
 void
