@@ -50,30 +50,58 @@ class Manager;
 
 class Window {
 public:
+  typedef uint32_t extent_type;
+
   typedef rak::mem_fun0<Manager, void>                      Slot;
   typedef rak::mem_fun1<Manager, void, Window*>             SlotWindow;
   typedef rak::mem_fun2<Manager, void, Window*, rak::timer> SlotTimer;
 
-  Window(Canvas* c = NULL, bool d = false, int h = 1);
+  static const int flag_active    = (1 << 0);
+  static const int flag_offscreen = (1 << 1);
+  static const int flag_left      = (1 << 2);
+  static const int flag_bottom    = (1 << 3);
+
+  static const extent_type extent_static = extent_type();
+  static const extent_type extent_full   = ~extent_type();
+
+  Window(Canvas* canvas, int flags,
+         extent_type minWidth, extent_type minHeight,
+         extent_type maxWidth, extent_type maxHeight);
 
   virtual ~Window();
 
-  bool                is_active()                          { return m_active; }
-  bool                is_dynamic()                         { return m_dynamic; }
+  bool                is_active() const                    { return m_flags & flag_active; }
+  void                set_active(bool state);
+
+  bool                is_offscreen() const                 { return m_flags & flag_offscreen; }
+  void                set_offscreen(bool state)            { if (state) m_flags |= flag_offscreen; else m_flags &= ~flag_offscreen; }
+
+  bool                is_left() const                      { return m_flags & flag_left; }
+  void                set_left(bool state)                 { if (state) m_flags |= flag_left; else m_flags &= ~flag_left; }
+
+  bool                is_bottom() const                    { return m_flags & flag_bottom; }
+  void                set_bottom(bool state)               { if (state) m_flags |= flag_bottom; else m_flags &= ~flag_bottom; }
+
+  bool                is_width_dynamic() const             { return m_maxWidth > m_minWidth; }
+  bool                is_height_dynamic() const            { return m_maxHeight > m_minHeight; }
+
+  // Do not call mark_dirty() from withing redraw() as it may cause
+  // infinite looping in the display scheduler.
   bool                is_dirty()                           { return m_taskUpdate.is_queued(); }
+  void                mark_dirty()                         { if (!is_active()) return; m_slotSchedule(this, cachedTime); }
 
-  int                 get_min_height() const               { return m_minHeight; }
+  extent_type         min_width() const                    { return m_minWidth; }
+  extent_type         min_height() const                   { return m_minHeight; }
 
-  bool                get_active()                         { return m_active; }
-  void                set_active(bool a);
+  extent_type         max_width() const                    { return std::max(m_maxWidth, m_minWidth); }
+  extent_type         max_height() const                   { return std::max(m_maxHeight, m_minHeight); }
+
+  extent_type         width() const                        { return m_canvas->width(); }
+  extent_type         height() const                       { return m_canvas->height(); }
 
   void                refresh()                            { m_canvas->refresh(); }
   void                resize(int x, int y, int w, int h);
 
-  int                 get_height() const                   { return m_canvas->get_height(); }
-
-  void                mark_dirty()                         { m_slotSchedule(this, cachedTime + 1); }
-
   virtual void        redraw() = 0;
 
   rak::priority_item* task_update()                        { return &m_taskUpdate; }
@@ -93,9 +121,13 @@ protected:
 
   Canvas*             m_canvas;
 
-  bool                m_active;
-  bool                m_dynamic;
-  int                 m_minHeight;
+  int                 m_flags;
+
+  extent_type         m_minWidth;
+  extent_type         m_minHeight;
+
+  extent_type         m_maxWidth;
+  extent_type         m_maxHeight;
 
   rak::priority_item  m_taskUpdate;
 };
