@@ -54,9 +54,9 @@ public:
   virtual void     redraw();
 
   unsigned int     rows() const;
-  unsigned int     chunks_per_row() const   { return (m_canvas->get_width() - 6) / 11 * 10; }
+  unsigned int     chunks_per_row() const   { return (width() - 6) / 11 * 10; }
 
-  unsigned int     max_focus() const        { return std::max<int>(rows() - get_height() + 1, 0); }
+  unsigned int     max_focus() const        { return std::max<int>(rows() - height() + 1, 0); }
 
 private:
   core::Download*  m_download;
