@@ -42,7 +42,7 @@
 #include "window.h"
 
 namespace torrent {
-  class Entry;
+  class File;
 }
 
 namespace core {
@@ -60,7 +60,7 @@ public:
   virtual void     redraw();
 
 private:
-  int              done_percentage(torrent::Entry& e);
+  int              done_percentage(torrent::File& e);
 
   core::Download*  m_download;
 
