@@ -44,15 +44,16 @@ namespace input {
 
 bool
 Bindings::pressed(int key) {
-  if (!m_active)
+  if (!m_enabled)
     return false;
 
   const_iterator itr = find(key);
 
-  if (itr != end())
-    itr->second();
+  if (itr == end())
+    return false;
 
-  return itr != end();
+  itr->second();
+  return true;
 }
 
 }
