@@ -126,10 +126,10 @@ load_arg_torrents(Control* c, char** first, char** last) {
   }
 }
 
-rak::timer
-client_next_timeout() {
+static inline rak::timer
+client_next_timeout(Control* c) {
   if (taskScheduler.empty())
-    return rak::timer::from_seconds(60);
+    return c->is_shutdown_started() ? rak::timer::from_milliseconds(100) : rak::timer::from_seconds(60);
   else if (taskScheduler.top()->time() <= cachedTime)
     return 0;
   else
@@ -141,7 +141,7 @@ main(int argc, char** argv) {
   try {
 
     // Temporary.
-    //setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "");
 
     cachedTime = rak::timer::current();
 
@@ -196,6 +196,7 @@ main(int argc, char** argv) {
     control->variable()->process_command("view_sort_new = incomplete,state_changed");
     control->variable()->process_command("view_sort_current = incomplete,state_changed_reverse");
 
+    // The hashing view does not include stopped torrents.
     control->variable()->process_command("view_add = hashing");
     control->variable()->process_command("view_filter = hashing,hashing");
     control->variable()->process_command("view_filter_on = hashing,hash_queued,hash_removed,hash_done");
@@ -243,7 +244,7 @@ main(int argc, char** argv) {
 
     while (!control->is_shutdown_completed()) {
       if (control->is_shutdown_received())
-	control->handle_shutdown();
+        control->handle_shutdown();
 
       control->inc_tick();
 
@@ -251,7 +252,7 @@ main(int argc, char** argv) {
       rak::priority_queue_perform(&taskScheduler, cachedTime);
 
       // Do shutdown check before poll, not after.
-      control->core()->get_poll_manager()->poll(client_next_timeout());
+      control->core()->get_poll_manager()->poll(client_next_timeout(control));
     }
 
     control->core()->download_list()->session_save();
@@ -325,6 +326,7 @@ print_help() {
   std::cout << "  ^q                Initiate shutdown or skip shutdown process" << std::endl;
   std::cout << "  a,s,d,z,x,c       Adjust upload throttle" << std::endl;
   std::cout << "  A,S,D,Z,X,C       Adjust download throttle" << std::endl;
+  std::cout << "  I                 Toggle whether torrent ignores ratio settings" << std::endl;
   std::cout << "  right             View torrent" << std::endl;
   std::cout << std::endl;
   std::cout << "Download view keys:" << std::endl;
