@@ -1,5 +1,5 @@
 // rTorrent - BitTorrent client
-// Copyright (C) 2005, Jari Sundell
+// Copyright (C) 2005-2006, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,56 +37,8 @@
 #ifndef RTORRENT_OPTION_HANDLER_RULES_H
 #define RTORRENT_OPTION_HANDLER_RULES_H
 
-#include <cstdio>
-#include <stdexcept>
-#include <sigc++/bind.h>
-
-#include "option_handler.h"
-
 class Control;
 
 void initialize_option_handler(Control* c);
 
-class OptionHandlerInt : public OptionHandlerBase {
-public:
-  typedef void (*Apply)(Control*, int);
-
-  OptionHandlerInt(Control* c, Apply a) :
-    m_control(c), m_apply(a) {}
-
-  virtual void process(const std::string& key, const std::string& arg);
-
-private:
-  Control* m_control;
-  Apply        m_apply;
-};
-
-class OptionHandlerOctal : public OptionHandlerBase {
-public:
-  typedef void (*Apply)(Control*, int);
-
-  OptionHandlerOctal(Control* c, Apply a) :
-    m_control(c), m_apply(a) {}
-
-  virtual void process(const std::string& key, const std::string& arg);
-
-private:
-  Control* m_control;
-  Apply        m_apply;
-};
-
-class OptionHandlerString : public OptionHandlerBase {
-public:
-  typedef void (*Apply)(Control*, const std::string&);
-
-  OptionHandlerString(Control* c, Apply a) :
-    m_control(c), m_apply(a) {}
-
-  virtual void process(const std::string& key, const std::string& arg);
-
-private:
-  Control*     m_control;
-  Apply        m_apply;
-};
-
 #endif
