@@ -36,8 +36,9 @@
 
 #include "config.h"
 
-#include <stdexcept>
+#include <torrent/exceptions.h>
 
+#include "display/frame.h"
 #include "display/window_download_chunks_seen.h"
 #include "input/manager.h"
 
@@ -51,35 +52,48 @@ ElementChunksSeen::ElementChunksSeen(core::Download* d) :
   m_window(NULL),
   m_focus(0) {
 
+  m_bindings[KEY_LEFT] = m_bindings['B' - '@'] = sigc::mem_fun(&m_slotExit, &slot_type::operator());
+
   m_bindings[KEY_DOWN]  = sigc::mem_fun(*this, &ElementChunksSeen::receive_next);
   m_bindings[KEY_UP]    = sigc::mem_fun(*this, &ElementChunksSeen::receive_prev);
   m_bindings[KEY_NPAGE] = sigc::mem_fun(*this, &ElementChunksSeen::receive_pagenext);
   m_bindings[KEY_PPAGE] = sigc::mem_fun(*this, &ElementChunksSeen::receive_pageprev);
-//   m_bindings[' ']      = sigc::mem_fun(*this, &ElementChunksSeen::receive_cycle_group);
-//   m_bindings['*']      = sigc::mem_fun(*this, &ElementChunksSeen::receive_disable);
 }
 
 void
-ElementChunksSeen::activate(Control* c, MItr mItr) {
-  if (m_window != NULL)
-    throw std::logic_error("ui::ElementChunksSeen::activate(...) called on an object in the wrong state");
+ElementChunksSeen::activate(display::Frame* frame, bool focus) {
+  if (is_active())
+    throw torrent::client_error("ui::ElementChunksSeen::activate(...) is_active().");
 
-  c->input()->push_front(&m_bindings);
+  if (focus)
+    control->input()->push_back(&m_bindings);
 
-  *mItr = m_window = new WChunksSeen(m_download, &m_focus);
+  m_window = new WChunksSeen(m_download, &m_focus);
+  m_window->set_active(true);
+
+  m_frame = frame;
+  m_frame->initialize_window(m_window);
 }
 
 void
-ElementChunksSeen::disable(Control* c) {
-  if (m_window == NULL)
-    throw std::logic_error("ui::ElementChunksSeen::disable(...) called on an object in the wrong state");
+ElementChunksSeen::disable() {
+  if (!is_active())
+    throw torrent::client_error("ui::ElementChunksSeen::disable(...) !is_active().");
 
-  c->input()->erase(&m_bindings);
+  control->input()->erase(&m_bindings);
+
+  m_frame->clear();
+  m_frame = NULL;
 
   delete m_window;
   m_window = NULL;
 }
 
+display::Window*
+ElementChunksSeen::window() {
+  return m_window;
+}
+
 // void
 // ElementChunksSeen::receive_disable() {
 //   if (m_window == NULL)
@@ -122,7 +136,7 @@ ElementChunksSeen::receive_pagenext() {
   if (m_window == NULL)
     throw torrent::client_error("ui::ElementChunksSeen::receive_pagenext(...) called on a disabled object");
 
-  unsigned int visible = m_window->get_height() - 1;
+  unsigned int visible = m_window->height() - 1;
   unsigned int scrollable = std::max<int>(m_window->rows() - visible, 0);
 
   if (scrollable == 0 || m_focus == scrollable)
@@ -140,7 +154,7 @@ ElementChunksSeen::receive_pageprev() {
   if (m_window == NULL)
     throw torrent::client_error("ui::ElementChunksSeen::receive_pageprev(...) called on a disabled object");
 
-  unsigned int visible = m_window->get_height() - 1;
+  unsigned int visible = m_window->height() - 1;
   unsigned int scrollable = std::max<int>(m_window->rows() - visible, 0);
 
   if (m_focus > visible / 2)
