@@ -39,6 +39,8 @@
 #include <torrent/exceptions.h>
 #include <torrent/file_list.h>
 
+#include "display/frame.h"
+#include "display/manager.h"
 #include "display/window_file_list.h"
 #include "input/manager.h"
 
@@ -52,35 +54,53 @@ ElementFileList::ElementFileList(core::Download* d) :
   m_window(NULL),
   m_focus(0) {
 
+  m_bindings[KEY_LEFT] = m_bindings['B' - '@'] = sigc::mem_fun(&m_slotExit, &slot_type::operator());
+
   m_bindings[' '] = sigc::mem_fun(*this, &ElementFileList::receive_priority);
   m_bindings['*'] = sigc::mem_fun(*this, &ElementFileList::receive_change_all);
-  m_bindings[KEY_DOWN] = sigc::mem_fun(*this, &ElementFileList::receive_next);
-  m_bindings[KEY_UP] = sigc::mem_fun(*this, &ElementFileList::receive_prev);
   m_bindings[KEY_NPAGE] = sigc::mem_fun(*this, &ElementFileList::receive_pagenext);
   m_bindings[KEY_PPAGE] = sigc::mem_fun(*this, &ElementFileList::receive_pageprev);
+
+  m_bindings[KEY_DOWN] = m_bindings['N' - '@'] = sigc::mem_fun(*this, &ElementFileList::receive_next);
+  m_bindings[KEY_UP]   = m_bindings['P' - '@'] = sigc::mem_fun(*this, &ElementFileList::receive_prev);
 }
 
 void
-ElementFileList::activate(Control* c, MItr mItr) {
+ElementFileList::activate(display::Frame* frame, bool focus) {
   if (m_window != NULL)
-    throw torrent::client_error("ui::ElementFileList::activate(...) called on an object in the wrong state");
+    throw torrent::client_error("ui::ElementFileList::activate(...) is_active().");
 
-  c->input()->push_front(&m_bindings);
+  if (focus)
+    control->input()->push_back(&m_bindings);
 
-  *mItr = m_window = new WFileList(m_download, &m_focus);
+  m_window = new WFileList(m_download, &m_focus);
+  m_window->set_active(true);
+
+  m_frame = frame;
+  m_frame->initialize_window(m_window);
+
+//   control->display()->adjust_layout();
 }
 
 void
-ElementFileList::disable(Control* c) {
+ElementFileList::disable() {
   if (m_window == NULL)
-    throw torrent::client_error("ui::ElementFileList::disable(...) called on an object in the wrong state");
+    throw torrent::client_error("ui::ElementFileList::disable(...) !is_active().");
 
-  c->input()->erase(&m_bindings);
+  control->input()->erase(&m_bindings);
+
+  m_frame->clear();
+  m_frame = NULL;
 
   delete m_window;
   m_window = NULL;
 }
 
+display::Window*
+ElementFileList::window() {
+  return m_window;
+}
+
 void
 ElementFileList::receive_next() {
   if (m_window == NULL)
@@ -115,7 +135,7 @@ ElementFileList::receive_pagenext() {
   if (m_window == NULL)
     throw torrent::client_error("ui::ElementFileList::receive_pagenext(...) called on a disabled object");
 
-  unsigned int count = (m_window->get_height() - 1) / 2;
+  unsigned int count = (m_window->height() - 1) / 2;
 
   if (m_focus + count < m_download->download()->file_list().size())
     m_focus += count;
@@ -137,7 +157,7 @@ ElementFileList::receive_pageprev() {
   if (fl.size() == 0)
     return;
 
-  unsigned int count = (m_window->get_height() - 1) / 2;
+  unsigned int count = (m_window->height() - 1) / 2;
 
   if (m_focus > count)
     m_focus -= count;
