@@ -40,6 +40,7 @@
 #include <torrent/tracker.h>
 #include <torrent/tracker_list.h>
 
+#include "display/frame.h"
 #include "display/window_tracker_list.h"
 #include "input/manager.h"
 
@@ -53,33 +54,49 @@ ElementTrackerList::ElementTrackerList(core::Download* d) :
   m_window(NULL),
   m_focus(0) {
 
-  m_bindings[KEY_DOWN] = sigc::mem_fun(*this, &ElementTrackerList::receive_next);
-  m_bindings[KEY_UP]   = sigc::mem_fun(*this, &ElementTrackerList::receive_prev);
+  m_bindings[KEY_LEFT] = m_bindings['B' - '@'] = sigc::mem_fun(&m_slotExit, &slot_type::operator());
+
   m_bindings[' ']      = sigc::mem_fun(*this, &ElementTrackerList::receive_cycle_group);
   m_bindings['*']      = sigc::mem_fun(*this, &ElementTrackerList::receive_disable);
+
+  m_bindings[KEY_DOWN] = m_bindings['N' - '@'] = sigc::mem_fun(*this, &ElementTrackerList::receive_next);
+  m_bindings[KEY_UP]   = m_bindings['P' - '@'] = sigc::mem_fun(*this, &ElementTrackerList::receive_prev);
 }
 
 void
-ElementTrackerList::activate(Control* c, MItr mItr) {
+ElementTrackerList::activate(display::Frame* frame, bool focus) {
   if (m_window != NULL)
-    throw torrent::client_error("ui::ElementTrackerList::activate(...) called on an object in the wrong state");
+    throw torrent::client_error("ui::ElementTrackerList::activate(...) is_active().");
 
-  c->input()->push_front(&m_bindings);
+  if (focus)
+    control->input()->push_back(&m_bindings);
 
-  *mItr = m_window = new WTrackerList(m_download, &m_focus);
+  m_window = new WTrackerList(m_download, &m_focus);
+  m_window->set_active(true);
+
+  m_frame = frame;
+  m_frame->initialize_window(m_window);
 }
 
 void
-ElementTrackerList::disable(Control* c) {
+ElementTrackerList::disable() {
   if (m_window == NULL)
-    throw torrent::client_error("ui::ElementTrackerList::disable(...) called on an object in the wrong state");
+    throw torrent::client_error("ui::ElementTrackerList::disable(...) !is_active().");
 
-  c->input()->erase(&m_bindings);
+  control->input()->erase(&m_bindings);
+
+  m_frame->clear();
+  m_frame = NULL;
 
   delete m_window;
   m_window = NULL;
 }
 
+display::Window*
+ElementTrackerList::window() {
+  return m_window;
+}
+
 void
 ElementTrackerList::receive_disable() {
   if (m_window == NULL)
