@@ -55,8 +55,10 @@ public:
 
   ElementTransferList(core::Download* d);
 
-  void                activate(Control* c, MItr mItr);
-  void                disable(Control* c);
+  void                activate(display::Frame* frame, bool focus = true);
+  void                disable();
+
+  display::Window*    window();
 
 private:
 //   void                receive_disable();
